/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

export { isDeleted as default } from 'kv/utils/kv-deleted';
